pygeodesy.triaxials.triaxial5.Triaxial_

Package pygeodesy :: Package triaxials :: Module triaxial5 :: Class Triaxial_ |
[frames] | no frames]

# Class Triaxial_

          object --+
                   |
        named._Named --+
                       |
        named._NamedBase --+
                           |
        named._NamedEnumItem --+
                               |
    bases._UnOrderedTriaxialBase --+
                                   |
                                  Triaxial_

Unordered triaxial ellipsoid.

Triaxial ellipsoids with right-handed semi-axes `a`, `b` and `c`, oriented such that the large principal ellipse `ab` is the equator Z=0, beta=0, while the small principal ellipse `ac` is the prime meridian, plane Y=0, omega=0.

The four umbilic points, `abs`(omega) = `abs`(beta) = `PI/2`, lie on the middle principal ellipse `bc` in plane X=0, omega=`PI/2`.

Note: Geodetic `lat`- and `lon`gitudes are in `degrees`, geodetic `phi` and `lam`bda are in `radians`, but ellipsoidal lat- and longitude `beta` and `omega` are in Radians by default (or in Degrees if converted).

Instance Methods
__init__(self, a_triaxial, b=None, c=None, **name) New unordered `Triaxial_`. |
Inherited from `bases._UnOrderedTriaxialBase`: `__repr__`, `areaKT`, `area_p`, `ellipse5`, `hartzell4`, `height4`, `normal3d`, `normal4`, `sideOf`, `toBiaxial`, `toEllipsoid`, `toStr` Inherited from `named._NamedEnumItem`: `unregister` Inherited from `named._NamedBase`: `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `bases._UnOrderedTriaxialBase`: `R2`, `R3`, `Rauthalic`, `Rvolumetric`, `a`, `a2`, `abc3`, `area`, `areaRG`, `b`, `b2`, `c`, `c2`, `e2ab`, `e2ac`, `e2bc`, `isFlat`, `isOblate`, `isOrdered`, `isProlate`, `isSpherical`, `perimeter4ab`, `perimeter4ac`, `perimeter4bc`, `unOrdered`, `volume` Inherited from `named._NamedEnumItem`: `name` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, a_triaxial, b=None, c=None, **name) (Constructor) |
New unordered `Triaxial_`. Arguments: `a_triaxial` - Large, `X` semi-axis (`scalar`, conventionally in `meter`) or an other Triaxial, Triaxial_ or TriaxialB instance. `b` - Middle, `Y` semi-axis (`meter`, same units as `a`), required if `a_triaxial is scalar`, ignored otherwise. `c` - Small, `Z` semi-axis (`meter`, like `b`). `name` - Optional `name=NN` (`str`). Raises: `TriaxialError` - Invalid semi-axis or -axes. Overrides: object.__init__